@@ -3,11 +3,11 @@ from typing import List
 from .resource_utils import resources_from_json, resources_from_key_file, \
     googleads_client_from_yaml, googleads_client_from_key_file
 from .googalytics_wrapper import GoogalyticsWrapper
-from kwp_wrappers import KeywordPlanIdeaService, KeywordPlanService
+from .kwp_wrappers import KeywordPlanIdeaService, KeywordPlanService
 from . import pga_logger
 
 
-class GoogalticsClient:
+class GoogalyticsClient:
     """
     The Client class holds the credentials for a project
     which can then be used to create a GoogalyticsWrapper object.
